@@ -1,3 +1,4 @@
 library(testthat)
-library("rcites")
+library(rcites)
+library(tibble)
 test_check("rcites")
